@@ -15,7 +15,7 @@ class PropertyVector(FitnessCalculator):
     --------
     *Calculating Fitness Values*
 
-    .. code-block:: python
+    .. testcode:: calculating-fitness-values
 
         import stk
 
@@ -46,12 +46,51 @@ class PropertyVector(FitnessCalculator):
             molecule=stk.BuildingBlock('BrCCBr'),
         )
 
+    .. testcode:: calculating-fitness-values
+        :hide:
+
+        _bb = stk.BuildingBlock('BrCCBr')
+        assert value == (
+            _bb.get_num_atoms(),
+            _bb.get_num_bonds(),
+            _bb.get_maximum_diameter(),
+        )
+
     *Storing Fitness Values in a Database*
 
     Sometimes you want to store fitness values in a database, you
     can do this by providing the `output_database` parameter.
 
-    .. code-block:: python
+    .. testsetup:: storing-fitness-values-in-a-database
+
+        import stk
+
+        # Change the database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+        _old_init = stk.ValueMongoDb
+        stk.ValueMongoDb = lambda mongo_client, collection: (
+            _old_init(
+                mongo_client=mongo_client,
+                database=_test_database,
+                collection=collection,
+            )
+        )
+
+        # Change the database MongoClient will connect to.
+
+        import os
+        import pymongo
+
+        _mongo_client = pymongo.MongoClient
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        pymongo.MongoClient = lambda: _mongo_client(_mongodb_uri)
+
+    .. testcode:: storing-fitness-values-in-a-database
 
         import stk
         import pymongo
@@ -93,7 +132,18 @@ class PropertyVector(FitnessCalculator):
         )
 
         # You can retrieve the fitness values from the database.
-        value = fitness_db.get(stk.BuildingBlock('BrCCBr'))
+        value2 = fitness_db.get(stk.BuildingBlock('BrCCBr'))
+
+    .. testcode:: storing-fitness-values-in-a-database
+        :hide:
+
+        assert value1 == tuple(value2)
+
+    .. testcleanup:: storing-fitness-values-in-a-database
+
+        stk.ValueMongoDb = _old_init
+        pymongo.MongoClient().drop_database(_test_database)
+        pymongo.MongoClient = _mongo_client
 
     *Caching Fitness Values*
 
@@ -109,7 +159,36 @@ class PropertyVector(FitnessCalculator):
     see if the value already exists, while the `output_database` has
     the calculated fitness value deposited into it.
 
-    .. code-block:: python
+    .. testsetup:: caching-fitness-values
+
+        import stk
+
+        # Change the database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+        _old_init = stk.ValueMongoDb
+        stk.ValueMongoDb = lambda mongo_client, collection: (
+            _old_init(
+                mongo_client=mongo_client,
+                database=_test_database,
+                collection=collection,
+            )
+        )
+
+        # Change the database MongoClient will connect to.
+
+        import os
+        import pymongo
+
+        _mongo_client = pymongo.MongoClient
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        pymongo.MongoClient = lambda: _mongo_client(_mongodb_uri)
+
+    .. testcode:: caching-fitness-values
 
         import stk
         import pymongo
@@ -158,6 +237,20 @@ class PropertyVector(FitnessCalculator):
             molecule=stk.BuildingBlock('BrCCBr'),
         )
 
+    .. testcode:: caching-fitness-values
+        :hide:
+
+        value3 = fitness_calculator.get_fitness_value(
+            molecule=stk.BuildingBlock('BrCCBr'),
+        )
+        assert value2 is value3
+
+    .. testcleanup:: caching-fitness-values
+
+        stk.ValueMongoDb = _old_init
+        pymongo.MongoClient().drop_database(_test_database)
+        pymongo.MongoClient = _mongo_client
+
     """
 
     def __init__(
@@ -172,7 +265,7 @@ class PropertyVector(FitnessCalculator):
 
         Parameters
         ----------
-        property_fns : :class:`tuple` of :class:`callable`
+        property_functions: :class:`tuple` of :class:`callable`
             A group of :class:`function`, each of which is used to
             calculate a single property of the molecule. Each function
             must take one parameter, `mol`, which accepts
@@ -196,7 +289,21 @@ class PropertyVector(FitnessCalculator):
         self._output_database = output_database
 
     def get_fitness_value(self, molecule):
-        return tuple(
-            property_function(molecule)
-            for property_function in self._property_functions
-        )
+        if self._input_database is not None:
+            try:
+                fitness_value = self._input_database.get(molecule)
+            except KeyError:
+                fitness_value = tuple(
+                    property_function(molecule)
+                    for property_function in self._property_functions
+                )
+        else:
+            fitness_value = tuple(
+                property_function(molecule)
+                for property_function in self._property_functions
+            )
+
+        if self._output_database is not None:
+            self._output_database.put(molecule, fitness_value)
+
+        return fitness_value
