@@ -4,27 +4,32 @@ Key Maker Utilities
 
 """
 
+from __future__ import annotations
+
 import rdkit.Chem.AllChem as rdkit
 
+from ..molecules import Molecule
 
-def get_inchi(molecule):
+
+def get_inchi(
+    molecule: Molecule,
+):
     """
     Get the InChI of `molecule`.
 
-    Parameters
-    ----------
-    molecule : :class:`.Molecule`
-        The molecule whose InChI is required.
+    Parameters:
+
+        molecule:
+            The molecule whose InChI is required.
+
+    Returns:
 
-    Returns
-    -------
-    :class:`str`
         The InChI.
 
-    Raises
-    ------
-    :class:`ValueError`
-        If the InChI of `molecule` cannot be generated.
+    Raises:
+
+        :class:`ValueError`
+            If the InChI of `molecule` cannot be generated.
 
     """
 
@@ -34,24 +39,25 @@ def get_inchi(molecule):
     raise ValueError('The InChI of {molecule} was empty.')
 
 
-def get_inchi_key(molecule):
+def get_inchi_key(
+    molecule: Molecule,
+) -> str:
     """
     Get the InChIKey of `molecule`.
 
-    Parameters
-    ----------
-    molecule : :class:`.Molecule`
-        The molecule whose InChIKey is needed.
+    Parameters:
+
+        molecule:
+            The molecule whose InChIKey is needed.
+
+    Returns:
 
-    Returns
-    -------
-    :class:`str`
         The InChIKey.
 
-    Raises
-    ------
-    :class:`ValueError`
-        If the InChIKey of `molecule` cannot be generated.
+    Raises:
+
+        :class:`ValueError`
+            If the InChIKey of `molecule` cannot be generated.
 
     """
 
@@ -61,18 +67,17 @@ def get_inchi_key(molecule):
     return key
 
 
-def get_smiles(molecule):
+def get_smiles(molecule: Molecule) -> str:
     """
     Get the RDKit canonical, isomeric SMILES of `molecule`.
 
-    Parameters
-    ----------
-    molecule : :class:`.Molecule`
-        The molecule whose SMILES is required.
+    Parameters:
+
+        molecule:
+            The molecule whose SMILES is required.
+
+    Returns:
 
-    Returns
-    -------
-    :class:`str`
         The SMILES.
 
     """
